==> kdevplatform-1.5.80.tar.xz: kdevplatform-1.5.80/plugins/projectfilter/kdevprojectfilter.desktop.cmake <==
[Desktop Entry]
Type=Service
ServiceTypes=KDevelop/Plugin

Icon=view-filter

X-KDE-Library=kdevprojectfilter
X-KDE-PluginInfo-Name=KDevProjectFilter
X-KDE-PluginInfo-Author=Milian Wolff
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Interfaces=org.kdevelop.IProjectFilter

X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Mode=GUI
X-KDevelop-LoadMode=AlwaysOn

Name=Project Filter
Name[cs]=Filtr projektů
Name[de]=Projektfilter
Name[es]=Filtro del proyecto
Name[fi]=Projektisuodatin
Name[fr]=Filtre de projet
Name[gl]=Filtro do proxecto
Name[hu]=Projektszűrő
Name[it]=Filtro progetto
Name[nl]=Projectfilter
Name[pt]=Filtro de Projectos
Name[pt_BR]=Filtro de projetos
Name[sl]=Filter projektov
Name[sv]=Projektfilter
Name[uk]=Фільтр проекту
Name[x-test]=xxProject Filterxx
Name[zh_TW]=專案過濾器
Comment=Configure which files and folders inside the project folder should be included or excluded.
Comment[de]=Legt fest, welche Dateien und Ordner innerhalb des Projektordners ein- oder ausgeschlossen werden sollen.
Comment[es]=Configura qué archivos y carpetas contenidos en la carpeta del proyecto se deben incluir o excluir.
Comment[fr]=Configure quels fichiers et dossier au sein du projet doivent être inclus ou exclus.
Comment[gl]=Configurar cales ficheiros e cartafoles dentro do cartafol do proxecto deben incluírse ou excluírse.
Comment[it]=Configura quali file e cartelle nella cartella del progetto devono essere incluse o escluse.
Comment[nl]=Stel in welke bestanden en mappen in de projectmap meegenomen of uitgesloten moeten worden.
Comment[pt]=Configura os ficheiros e pastas, dentro da pasta do projecto, que devem ser incluídos ou excluídos.
Comment[pt_BR]=Configura os arquivos e pastas, dentro da pasta do projeto, que devem ser incluídos ou excluídos.
Comment[sl]=Nastavi katere datoteke in mape znotraj mape projekta naj bodo vključene ali izključene.
Comment[sv]=Anpassa vilka filer och kataloger inne i projektkatalogen som ska inkluderas eller exkluderas.
Comment[uk]=За допомогою цього модуля можна визначити, які файли і теки у теці проекту має бути включено або виключено з його складу.
Comment[x-test]=xxConfigure which files and folders inside the project folder should be included or excluded.xx
Comment[zh_TW]=設定專案資料夾中要包含或排除哪些檔案與資料夾。

==> kdevplatform-1.5.90.tar.xz: kdevplatform-1.5.90/plugins/projectfilter/kdevprojectfilter.desktop.cmake <==
[Desktop Entry]
Type=Service
ServiceTypes=KDevelop/Plugin

Icon=view-filter

X-KDE-Library=kdevprojectfilter
X-KDE-PluginInfo-Name=KDevProjectFilter
X-KDE-PluginInfo-Author=Milian Wolff
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Interfaces=org.kdevelop.IProjectFilter

X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Mode=GUI
X-KDevelop-LoadMode=AlwaysOn

Name=Project Filter
Name[bs]=Projekt Filter
Name[ca]=Filtre de projecte
Name[cs]=Filtr projektů
Name[de]=Projektfilter
Name[es]=Filtro del proyecto
Name[fi]=Projektisuodatin
Name[fr]=Filtre de projet
Name[gl]=Filtro do proxecto
Name[hu]=Projektszűrő
Name[it]=Filtro progetto
Name[kk]=Жоба сүзгісі
Name[nb]=Prosjektfilter
Name[nl]=Projectfilter
Name[pt]=Filtro de Projectos
Name[pt_BR]=Filtro de projetos
Name[sk]=Filter projektu
Name[sl]=Filter projektov
Name[sv]=Projektfilter
Name[uk]=Фільтр проекту
Name[x-test]=xxProject Filterxx
Name[zh_TW]=專案過濾器
Comment=Configure which files and folders inside the project folder should be included or excluded.
Comment[bs]=Konfiguriši koje datoteke i direktoriji unutar projekta trebaju biti uključeni ili isključeni.
Comment[ca]=Configura quins fitxers i carpetes dins de la carpeta del projecte s'han d'incloure o excloure.
Comment[de]=Legt fest, welche Dateien und Ordner innerhalb des Projektordners ein- oder ausgeschlossen werden sollen.
Comment[es]=Configura qué archivos y carpetas contenidos en la carpeta del proyecto se deben incluir o excluir.
Comment[fi]=Valitse, mitkä projektikansiossa olevat tiedostot ja kansiot pitäisi ottaa mukaan ja mitkä pitäisi jättää pois.
Comment[fr]=Configure quels fichiers et dossier au sein du projet doivent être inclus ou exclus.
Comment[gl]=Configurar cales ficheiros e cartafoles dentro do cartafol do proxecto deben incluírse ou excluírse.
Comment[it]=Configura quali file e cartelle nella cartella del progetto devono essere incluse o escluse.
Comment[kk]=Жоба қапшығындағы қай файлдар мен қапшықтарды есепке кіргізу қайсын кіргізбеу керек.
Comment[nb]=Bestem hvilke filer og mapper inni prosjektmappa skal tas med eller utelates.
Comment[nl]=Stel in welke bestanden en mappen in de projectmap meegenomen of uitgesloten moeten worden.
Comment[pt]=Configura os ficheiros e pastas, dentro da pasta do projecto, que devem ser incluídos ou excluídos.
Comment[pt_BR]=Configura os arquivos e pastas, dentro da pasta do projeto, que devem ser incluídos ou excluídos.
Comment[sk]=Nastaviť, ktoré súbory a priečinky v priečinku projektu majú byť zahrnuté alebo vylúčené.
Comment[sl]=Nastavi katere datoteke in mape znotraj mape projekta naj bodo vključene ali izključene.
Comment[sv]=Anpassa vilka filer och kataloger inne i projektkatalogen som ska inkluderas eller exkluderas.
Comment[uk]=За допомогою цього модуля можна визначити, які файли і теки у теці проекту має бути включено або виключено з його складу.
Comment[x-test]=xxConfigure which files and folders inside the project folder should be included or excluded.xx
Comment[zh_TW]=設定專案資料夾中要包含或排除哪些檔案與資料夾。
